@@ -102,8 +102,8 @@ class SimpleConsumer:
                 raise tTransportException
 
         # update scheduleInfocache when request have been transfered and talos auto location was set up
-        if getMessageResponse.isTransfer is not None and getMessageResponse.isTransfer and self.scheduleInfoCache is not None \
-                and self.scheduleInfoCache.get_is_auto_location():
+        if self.scheduleInfoCache.get_is_auto_location()\
+                and self.scheduleInfoCache and getMessageResponse.isTransfer:
             self.logger.info("request has been transfered when talos auto location set up, refresh scheduleInfo")
             self.scheduleInfoCache.update_schedule_info_cache()
 
