@@ -20,6 +20,7 @@ from talos.thrift.consumer.ttypes import RenewResponse
 from talos.thrift.consumer.ttypes import RenewRequest
 from talos.thrift.consumer.ttypes import LockWorkerRequest
 from talos.client.TalosErrors import InvalidArgumentError
+from talos.client.ScheduleInfoCache import ScheduleInfoCache
 from talos.consumer.PartitionFetcher import PartitionFetcher
 from talos.thrift.common.ttypes import GalaxyTalosException
 from threading import Timer
@@ -119,6 +120,11 @@ class TalosConsumer(object):
             self.partitionCheckPoint = partitionCheckPoint
         else:
             self.partitionCheckPoint = dict()
+        # get scheduleInfo
+        self.scheduleInfoCache = ScheduleInfoCache().get_schedule_info_cache(
+            topicTalosResourceName=self.topicTalosResourceName.topicTalosResourceName,
+            talosClientConfig=consumerConfig, messageClient=self.talosClientFactory.new_message_client(),
+            talosClientFactory=self.talosClientFactory)
         self.falconWriter = FalconWriter(falconUrl=consumerConfig.get_falcon_url())
         self.isActive = True
 
@@ -624,5 +630,6 @@ class TalosConsumer(object):
         self.shut_down_fetcher()
         self.renewScheduleExecutor.cancel()
         self.consumerMonitorThread.cancel()
+        self.scheduleInfoCache.shut_down(self.topicTalosResourceName)
         self.isActive = False
         logger.info("Worker: " + self.workerId + " shutdown.")
